import { SummarizationModel, SummarizationConfig } from '../types/models.js';
export declare class SummarizationService {
    private model;
    private config;
    private contentCache;
    private charThreshold;
    private cacheMaxAge;
    private cleanupInterval;
    constructor(model: SummarizationModel, config: SummarizationConfig);
    /**
     * Initialize the service and its model
     */
    initialize(): Promise<void>;
    /**
     * Clean up expired cache entries
     */
    private cleanupCache;
    /**
     * Store content in the cache and return its ID
     */
    private storeContent;
    /**
     * Retrieve content from the cache by ID
     */
    getFullContent(id: string): string | null;
    /**
     * Summarize content if it exceeds the threshold
     * @returns The original content if below threshold, or a summary with the original content's ID
     */
    maybeSummarize(content: string, type: string, options?: {
        hint?: string;
        output_format?: string;
    }): Promise<{
        text: string;
        id?: string;
        isSummarized: boolean;
    }>;
    /**
     * Clean up resources
     */
    cleanup(): Promise<void>;
}
